# Bibliograhy

<div class="csl-bib-body" style="line-height: 1.35; margin-left: 2em; text-indent:-2em;">
  <div class="csl-entry">Kveim Lie, Anne Helene, Lars G. Johnsen, Helge Jordheim, and Espen Ytreberg. “The Rise of Health: A Collocation Analysis of Conceptual Changes in News Discourse, 1950–2010.” <i>Contributions to the History of Concepts</i> 17, no. 2 (December 1, 2022): 18–40. <a href="https://doi.org/10.3167/choc.2022.170202">https://doi.org/10.3167/choc.2022.170202</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_id=info%3Adoi%2F10.3167%2Fchoc.2022.170202&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.atitle=The%20Rise%20of%20Health%3A%20A%20Collocation%20Analysis%20of%20Conceptual%20Changes%20in%20News%20Discourse%2C%201950%E2%80%932010&amp;rft.jtitle=Contributions%20to%20the%20History%20of%20Concepts&amp;rft.volume=17&amp;rft.issue=2&amp;rft.aufirst=Anne%20Helene&amp;rft.aulast=Kveim%20Lie&amp;rft.au=Anne%20Helene%20Kveim%20Lie&amp;rft.au=Lars%20G.%20Johnsen&amp;rft.au=Helge%20Jordheim&amp;rft.au=Espen%20Ytreberg&amp;rft.date=2022-12-01&amp;rft.pages=18-40&amp;rft.spage=18&amp;rft.epage=40&amp;rft.issn=1807-9326%2C%201874-656X"></span>
  <div class="csl-entry">Tonne, Ingebjørg, Helene Uri, and Lars Johnsen. “Om Kjønn Og Adjektiv: «Trond Er Så Eksepsjonell/Nydelig/Skjønn/Grønn».” <i>Nordlyd</i> 46, no. 1 (August 30, 2022). <a href="https://doi.org/10.7557/12.6386">https://doi.org/10.7557/12.6386</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_id=info%3Adoi%2F10.7557%2F12.6386&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.atitle=Om%20kj%C3%B8nn%20og%20adjektiv%3A%20%C2%ABTrond%20er%20s%C3%A5%20eksepsjonell%2Fnydelig%2Fskj%C3%B8nn%2Fgr%C3%B8nn%C2%BB&amp;rft.jtitle=Nordlyd&amp;rft.stitle=NLY&amp;rft.volume=46&amp;rft.issue=1&amp;rft.aufirst=Ingebj%C3%B8rg&amp;rft.aulast=Tonne&amp;rft.au=Ingebj%C3%B8rg%20Tonne&amp;rft.au=Helene%20Uri&amp;rft.au=Lars%20Johnsen&amp;rft.date=2022-08-30&amp;rft.issn=1503-8599"></span>
  <div class="csl-entry">Johnsen, Lars G. “Term Distance, Frequency and Collocations.” In <i>Current Issues in Linguistic Theory</i>, edited by Adam Pawłowski, Jan Mačutek, Sheila Embleton, and George Mikros, 356:22–36. Amsterdam: John Benjamins Publishing Company, 2021. <a href="https://doi.org/10.1075/cilt.356.02joh">https://doi.org/10.1075/cilt.356.02joh</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_id=urn%3Aisbn%3A978-90-272-1010-4%20978-90-272-5838-0&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=bookitem&amp;rft.atitle=Term%20distance%2C%20frequency%20and%20collocations&amp;rft.place=Amsterdam&amp;rft.publisher=John%20Benjamins%20Publishing%20Company&amp;rft.aufirst=Lars%20G.&amp;rft.aulast=Johnsen&amp;rft.au=Adam%20Paw%C5%82owski&amp;rft.au=Jan%20Ma%C4%8Dutek&amp;rft.au=Sheila%20Embleton&amp;rft.au=George%20Mikros&amp;rft.au=Lars%20G.%20Johnsen&amp;rft.date=2021-12-15&amp;rft.pages=22-36&amp;rft.spage=22&amp;rft.epage=36&amp;rft.isbn=978-90-272-1010-4%20978-90-272-5838-0&amp;rft.language=en"></span>
  <div class="csl-entry">Uri, Helene, and Lars G. Johnsen. “Skjønnlitteraturen: en kroppsvisitasjon.” <i>Norsk barnebokinstitutt. Tidligere publisert i Samtiden 3/2021</i>, November 4, 2021. <a href="https://barnebokinstituttet.no/aktuelt/skjonnlitteraturen-en-kroppsvisitasjon/">https://barnebokinstituttet.no/aktuelt/skjonnlitteraturen-en-kroppsvisitasjon/</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Adc&amp;rft.type=newspaperArticle&amp;rft.title=Skj%C3%B8nnlitteraturen%3A%20en%20kroppsvisitasjon&amp;rft.source=Norsk%20barnebokinstitutt.%20Tidligere%20publisert%20i%20Samtiden%203%2F2021&amp;rft.description=Forfattere%20som%20en%20grensesprengende%20og%20nyskapende%20yrkesgruppe%3F%20Fordomsfrie%20folk%20som%20utfordrer%20det%20best%C3%A5ende%3F%20Nja%2C%20iallfall%20ikke%20i%20synet%20p%C3%A5%20kropp%20og%20kj%C3%B8nn.&amp;rft.identifier=https%3A%2F%2Fbarnebokinstituttet.no%2Faktuelt%2Fskjonnlitteraturen-en-kroppsvisitasjon%2F&amp;rft.aufirst=Helene&amp;rft.aulast=Uri&amp;rft.au=Helene%20Uri&amp;rft.au=Lars%20G.%20Johnsen&amp;rft.date=2021-11-04&amp;rft.language=nb-NO"></span>
  <div class="csl-entry">Karlsen, Heidi. “5. Kvinner i Nasjonalbibliotekets Digitaliserte Samlinger i Perioden 1830?1880: Etableringen Av En Minoriserende Diskurs.” <i>Minoritetsdiskurser i Norsk Litteratur</i>, Books, October 27, 2021, 93–113. <a href="https://doi.org/10.18261/9788215045320-2021-05">https://doi.org/10.18261/9788215045320-2021-05</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_id=info%3Adoi%2F10.18261%2F9788215045320-2021-05&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.atitle=5.%20Kvinner%20i%20Nasjonalbibliotekets%20digitaliserte%20samlinger%20i%20perioden%201830%3F1880%3A%20etableringen%20av%20en%20minoriserende%20diskurs&amp;rft.jtitle=Minoritetsdiskurser%20i%20norsk%20litteratur&amp;rft.aufirst=Heidi&amp;rft.aulast=Karlsen&amp;rft.au=Heidi%20Karlsen&amp;rft.date=2021-10-27&amp;rft.pages=93-113&amp;rft.spage=93&amp;rft.epage=113&amp;rft.issn=9788215045313"></span>
  <div class="csl-entry">Boasson, Frode Lerum, and Lars G. Johnsen. “Hamsuns Litterære Geografi.” <i>Nordlit</i>, no. 47 (December 15, 2020): 139–54. <a href="https://doi.org/10.7557/13.5725">https://doi.org/10.7557/13.5725</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_id=info%3Adoi%2F10.7557%2F13.5725&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.atitle=Hamsuns%20litter%C3%A6re%20geografi&amp;rft.jtitle=Nordlit&amp;rft.stitle=Nordlit&amp;rft.issue=47&amp;rft.aufirst=Frode%20Lerum&amp;rft.aulast=Boasson&amp;rft.au=Frode%20Lerum%20Boasson&amp;rft.au=Lars%20G.%20Johnsen&amp;rft.date=2020-12-15&amp;rft.pages=139-154&amp;rft.spage=139&amp;rft.epage=154&amp;rft.issn=1503-2086%2C%200809-1668"></span>
  <div class="csl-entry">Alsvik, Ola, and Marthe Glad Munch-Møller. “Historiografi møter algoritmer: Maskinell fjernlesning av lokalhistoriske framstillingerav kvinnehistorie, et supplement til nærlesning?” <i>Heimen</i> 57, no. 3 (October 14, 2020): 201–15. <a href="https://doi.org/10.18261/issn.1894-3195-2020-03-03">https://doi.org/10.18261/issn.1894-3195-2020-03-03</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_id=info%3Adoi%2F10.18261%2Fissn.1894-3195-2020-03-03&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.atitle=Historiografi%20m%C3%B8ter%20algoritmer%3A%20Maskinell%20fjernlesning%20av%20lokalhistoriske%20framstillingerav%20kvinnehistorie%2C%20et%20supplement%20til%20n%C3%A6rlesning%3F&amp;rft.jtitle=Heimen&amp;rft.stitle=Heimen&amp;rft.volume=57&amp;rft.issue=3&amp;rft.aufirst=Ola&amp;rft.aulast=Alsvik&amp;rft.au=Ola%20Alsvik&amp;rft.au=Marthe%20Glad%20Munch-M%C3%B8ller&amp;rft.date=2020-10-14&amp;rft.pages=201-215&amp;rft.spage=201&amp;rft.epage=215&amp;rft.issn=0017-9841%2C%201894-3195&amp;rft.language=no"></span>
  <div class="csl-entry">Dalen, Lars Sandved. “Forsiktige Forskere, Engasjerte Journalister.” <i>Mediehistorisk Tidsskrift</i> 34, no. 2 (2020): 186–92. <a href="https://www.pressetidsskrift.no/tidsskrift/medietidsskrift-nr-2-2020/">https://www.pressetidsskrift.no/tidsskrift/medietidsskrift-nr-2-2020/</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_id=info%3Adoi%2Fhttps%3A%2F%2Fwww.pressetidsskrift.no%2Ftidsskrift%2Fmedietidsskrift-nr-2-2020%2F&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.atitle=Forsiktige%20forskere%2C%20engasjerte%20journalister&amp;rft.jtitle=Mediehistorisk%20Tidsskrift&amp;rft.volume=34&amp;rft.issue=2&amp;rft.aufirst=Lars%20Sandved&amp;rft.aulast=Dalen&amp;rft.au=Lars%20Sandved%20Dalen&amp;rft.date=2020&amp;rft.pages=186-192&amp;rft.spage=186&amp;rft.epage=192"></span>
  <div class="csl-entry">Uri, Helene. “Helene Uri: Dette er en reklame for Norges stiligste nettsider.” <i>Aftenposten</i>, October 19, 2019. <a href="https://www.aftenposten.no/kultur/i/awkxj2/helene-uri-dette-er-en-reklametekst-for-norges-stiligste-nettside">https://www.aftenposten.no/kultur/i/awkxj2/helene-uri-dette-er-en-reklametekst-for-norges-stiligste-nettside</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Adc&amp;rft.type=newspaperArticle&amp;rft.title=Helene%20Uri%3A%20Dette%20er%20en%20reklame%20for%20Norges%20stiligste%20nettsider&amp;rft.source=Aftenposten&amp;rft.description=Siden%20det%20jeg%20reklamerer%20for%2C%20tilh%C3%B8rer%20folket%20og%20er%20finansiert%20av%20staten%2C%20synes%20jeg%20det%20er%20akseptabelt*.&amp;rft.identifier=https%3A%2F%2Fwww.aftenposten.no%2Fkultur%2Fi%2Fawkxj2%2Fhelene-uri-dette-er-en-reklametekst-for-norges-stiligste-nettside&amp;rft.aufirst=Helene&amp;rft.aulast=Uri&amp;rft.au=Helene%20Uri&amp;rft.date=2019-10-19&amp;rft.language=nb"></span>
  <div class="csl-entry">Boasson, Frode, and Anders Skare Malvik. “Digital humaniora, mediehistorie oglitterære subjektivitetsuttrykk. Om forholdet mellom norsk litteraturog utviklingen av den kommersielle pressen 1855–1900 i et DH‑perspektiv.” <i>Norsk litteraturvitenskapelig tidsskrift</i> 22, no. 2 (October 4, 2019): 146–67. <a href="https://doi.org/10.18261/issn.1504-288X-2019-02-03">https://doi.org/10.18261/issn.1504-288X-2019-02-03</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_id=info%3Adoi%2F10.18261%2Fissn.1504-288X-2019-02-03&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.atitle=Digital%20humaniora%2C%20mediehistorie%20oglitter%C3%A6re%20subjektivitetsuttrykk.%20Om%20forholdet%20mellom%20norsk%20litteraturog%20utviklingen%20av%20den%20kommersielle%20pressen%201855%E2%80%931900%20i%20et%20DH%E2%80%91perspektiv&amp;rft.jtitle=Norsk%20litteraturvitenskapelig%20tidsskrift&amp;rft.stitle=NLT&amp;rft.volume=22&amp;rft.issue=2&amp;rft.aufirst=Frode&amp;rft.aulast=Boasson&amp;rft.au=Frode%20Boasson&amp;rft.au=Anders%20Skare%20Malvik&amp;rft.date=2019-10-04&amp;rft.pages=146-167&amp;rft.spage=146&amp;rft.epage=167&amp;rft.issn=0809-2044%2C%201504-288X&amp;rft.language=no"></span>
  <div class="csl-entry">Bastiansen, Henrik G. “Når Mediehistorien Blir Søkbar – Og Grafisk.” <i>Mediehistorisk Tidsskrift</i>, 2019, 2 edition. <a href="https://www.pressetidsskrift.no/tidsskrift/mediehistorisk-tidsskrift-nr-2-2019-32/">https://www.pressetidsskrift.no/tidsskrift/mediehistorisk-tidsskrift-nr-2-2019-32/</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Adc&amp;rft.type=newspaperArticle&amp;rft.title=N%C3%A5r%20mediehistorien%20blir%20s%C3%B8kbar%20%E2%80%93%20og%20grafisk&amp;rft.source=Mediehistorisk%20Tidsskrift&amp;rft.identifier=https%3A%2F%2Fwww.pressetidsskrift.no%2Ftidsskrift%2Fmediehistorisk-tidsskrift-nr-2-2019-32%2F&amp;rft.aufirst=Henrik%20G.&amp;rft.aulast=Bastiansen&amp;rft.au=Henrik%20G.%20Bastiansen&amp;rft.date=2019"></span>
  <div class="csl-entry">Helland, Frode. <i>Rasismens Retorikk: Studier i Norsk Offentlighet</i>. Oslo: Pax Forlag, 2019. <a href="https://www.pax.no/rasismens-retorikk.6251805-331611.html">https://www.pax.no/rasismens-retorikk.6251805-331611.html</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_id=urn%3Aisbn%3A978-82-530-4092-9&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Rasismens%20retorikk%3A%20studier%20i%20norsk%20offentlighet&amp;rft.place=Oslo&amp;rft.publisher=Pax%20Forlag&amp;rft.aufirst=Frode&amp;rft.aulast=Helland&amp;rft.au=Frode%20Helland&amp;rft.date=2019&amp;rft.tpages=225&amp;rft.isbn=978-82-530-4092-9"></span>
  <div class="csl-entry">Johnsen, Lars G. “Eldre bøker i den digitale samlingen. Et elektronisk blikk på tekster fra perioden 1650-1850.” In <i>Litterære verdensborgere: transnasjonale perspektiver på norsk bokhistorie 1519-1850</i>, edited by Asta M. B. Bjørkøy, Ruth Hemstad, Aina Nøding, and Anne Birgitte Rønning, 190–214. Nota bene 13. Oslo: Nasjonalbiblioteket, 2019. <a href="https://issuu.com/nasjonalbiblioteket/docs/nota_bene_13_layout_rz_interaktiv__002_/188">https://issuu.com/nasjonalbiblioteket/docs/nota_bene_13_layout_rz_interaktiv__002_/188</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_id=urn%3Aisbn%3A978-82-7965-414-8&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=bookitem&amp;rft.atitle=Eldre%20b%C3%B8ker%20i%20den%20digitale%20samlingen.%20Et%20elektronisk%20blikk%20p%C3%A5%20tekster%20fra%20perioden%201650-1850&amp;rft.place=Oslo&amp;rft.publisher=Nasjonalbiblioteket&amp;rft.series=Nota%20bene&amp;rft.aufirst=Lars%20G.&amp;rft.aulast=Johnsen&amp;rft.au=Asta%20M.%20B.%20Bj%C3%B8rk%C3%B8y&amp;rft.au=Ruth%20Hemstad&amp;rft.au=Aina%20N%C3%B8ding&amp;rft.au=Anne%20Birgitte%20R%C3%B8nning&amp;rft.au=Lars%20G.%20Johnsen&amp;rft.date=2019&amp;rft.pages=190-214&amp;rft.spage=190&amp;rft.epage=214&amp;rft.isbn=978-82-7965-414-8&amp;rft.language=nor"></span>
  <div class="csl-entry">Karlsen, Heidi. “Sub-corpus topic modeling og diskursanalyse: gruvearbeid, tråling eller kokekunst?” <i>Samlaren: tidsskrift för forskning om svensk och annan nordisk litteratur</i> 140 (2019): 281–304. <a href="https://www.duo.uio.no/handle/10852/78112">https://www.duo.uio.no/handle/10852/78112</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_id=info%3Adoi%2Fhttps%3A%2F%2Fwww.duo.uio.no%2Fhandle%2F10852%2F78112&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.atitle=Sub-corpus%20topic%20modeling%20og%20diskursanalyse%3A%20gruvearbeid%2C%20tr%C3%A5ling%20eller%20kokekunst%3F&amp;rft.jtitle=Samlaren%3A%20tidsskrift%20f%C3%B6r%20forskning%20om%20svensk%20och%20annan%20nordisk%20litteratur&amp;rft.volume=140&amp;rft.aufirst=Heidi&amp;rft.aulast=Karlsen&amp;rft.au=Heidi%20Karlsen&amp;rft.date=2019&amp;rft.pages=281-304&amp;rft.spage=281&amp;rft.epage=304&amp;rft.language=NO"></span>
  <div class="csl-entry">Olsen, Ida Keihl. “Subjektplassering i moderne norsk - en korpusbasert analyse av leddstillingsvariasjon i bokmål det siste hundreåret,” 2019. <a href="https://www.duo.uio.no/handle/10852/69263">https://www.duo.uio.no/handle/10852/69263</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Adissertation&amp;rft.title=Subjektplassering%20i%20moderne%20norsk%20-%20en%20korpusbasert%20analyse%20av%20leddstillingsvariasjon%20i%20bokm%C3%A5l%20det%20siste%20hundre%C3%A5ret&amp;rft.aufirst=Ida%20Keihl&amp;rft.aulast=Olsen&amp;rft.au=Ida%20Keihl%20Olsen&amp;rft.date=2019&amp;rft.language=nob"></span>
  <div class="csl-entry">Hemstad, Ruth. “Scandinavianism.” <i>Contributions to the History of Concepts</i> 13, no. 1 (June 1, 2018): 1–21. <a href="https://doi.org/10.3167/choc.2018.130102">https://doi.org/10.3167/choc.2018.130102</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_id=info%3Adoi%2F10.3167%2Fchoc.2018.130102&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.atitle=Scandinavianism&amp;rft.jtitle=Contributions%20to%20the%20History%20of%20Concepts&amp;rft.volume=13&amp;rft.issue=1&amp;rft.aufirst=Ruth&amp;rft.aulast=Hemstad&amp;rft.au=Ruth%20Hemstad&amp;rft.date=2018-06-01&amp;rft.pages=1-21&amp;rft.spage=1&amp;rft.epage=21&amp;rft.issn=1807-9326%2C%201874-656X"></span>
  <div class="csl-entry">———. “Skandinavisme som omstridt begrep i nordisk offentlighet.” In <i>Skandinavismen: vision og virkning</i>, edited by Ruth Hemstad, Jes Fabricius Møller, and Dag Thorkildsen. University of Southern Denmark studies in history and social sciences, vol. 556. Odense: Syddansk Universitetsforlag, 2018. <a href="https://www.nb.no/items/81a1839cbe2ce0cd8211dbc8080d8491?page=21">https://www.nb.no/items/81a1839cbe2ce0cd8211dbc8080d8491?page=21</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_id=urn%3Aisbn%3A978-87-408-3121-4&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=bookitem&amp;rft.atitle=Skandinavisme%20som%20omstridt%20begrep%20i%20nordisk%20offentlighet&amp;rft.place=Odense&amp;rft.publisher=Syddansk%20Universitetsforlag&amp;rft.series=University%20of%20Southern%20Denmark%20studies%20in%20history%20and%20social%20sciences&amp;rft.aufirst=Ruth&amp;rft.aulast=Hemstad&amp;rft.au=Ruth%20Hemstad&amp;rft.au=Jes%20Fabricius%20M%C3%B8ller&amp;rft.au=Dag%20Thorkildsen&amp;rft.au=Ruth%20Hemstad&amp;rft.date=2018&amp;rft.isbn=978-87-408-3121-4&amp;rft.language=dan%20eng%20nor%20swe"></span>
  <div class="csl-entry">Bekeng-Flemmens, Haakon. “Ved et tideverv.” <i>Arr – idéhistorisk tidsskrift</i> 29, no. 2 (October 21, 2017). <a href="https://www.salongen.no/ved-et-tideverv/">https://www.salongen.no/ved-et-tideverv/</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.atitle=Ved%20et%20tideverv&amp;rft.jtitle=Arr%20%E2%80%93%20id%C3%A9historisk%20tidsskrift&amp;rft.volume=29&amp;rft.issue=2&amp;rft.aufirst=Haakon&amp;rft.aulast=Bekeng-Flemmens&amp;rft.au=Haakon%20Bekeng-Flemmens&amp;rft.date=2017-10-21&amp;rft.issn=ISSN%200802-7005&amp;rft.language=nb-NO"></span>
  <div class="csl-entry">Johnsen, Lars G. “Graph Analysis of Word Networks.” In <i>Extended Papers of the International Symposium on Digital Humanities (DH 2016) Växjö, Sweden, November, 7-8</i>, 2016. <a href="https://ceur-ws.org/Vol-2021/paper6.pdf">https://ceur-ws.org/Vol-2021/paper6.pdf</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=proceeding&amp;rft.atitle=Graph%20Analysis%20of%20Word%20Networks&amp;rft.btitle=Extended%20Papers%20of%20the%20International%20Symposium%20on%20Digital%20Humanities%20(DH%202016)%20V%C3%A4xj%C3%B6%2C%20Sweden%2C%20November%2C%207-8&amp;rft.aufirst=Lars%20G.&amp;rft.aulast=Johnsen&amp;rft.au=Lars%20G.%20Johnsen&amp;rft.date=2016"></span>
  <div class="csl-entry">Birkenes, Magnus Breder, Lars G. Johnsen, Arne M. Lindstad, and Johanne Ostad. “From Digital Library to N-Grams: NB N-Gram.” In <i>I Proceedings of the 20th Nordic Conference of Computational Linguistics, 293–295. Linköping: Linköping University Electronic Press.</i>, 2015. <a href="https://www.aclweb.org/anthology/W15-1839.pdf">https://www.aclweb.org/anthology/W15-1839.pdf</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=proceeding&amp;rft.atitle=From%20digital%20library%20to%20n-grams%3A%20NB%20N-gram&amp;rft.btitle=I%20Proceedings%20of%20the%2020th%20Nordic%20Conference%20of%20Computational%20Linguistics%2C%20293%E2%80%93295.%20Link%C3%B6ping%3A%20Link%C3%B6ping%20University%20Electronic%20Press.&amp;rft.aufirst=Magnus%20Breder&amp;rft.aulast=Birkenes&amp;rft.au=Magnus%20Breder%20Birkenes&amp;rft.au=Lars%20G.%20Johnsen&amp;rft.au=Arne%20M.%20Lindstad&amp;rft.au=Johanne%20Ostad&amp;rft.date=2015"></span>
  <div class="csl-entry">Olsen, Jon Arild. “Når Mer Er Bedre: Kvantitative Litteraturstudier.” <i>Norsk Litteraturvitenskapelig Tidsskrift</i> 17, no. 2 (August 29, 2014): 139–44. <a href="https://doi.org/10.18261/ISSN1504-288X-2014-02-06">https://doi.org/10.18261/ISSN1504-288X-2014-02-06</a>.</div>
  <span class="Z3988" title="url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_id=info%3Adoi%2F10.18261%2FISSN1504-288X-2014-02-06&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.atitle=N%C3%A5r%20mer%20er%20bedre%3A%20kvantitative%20litteraturstudier&amp;rft.jtitle=Norsk%20litteraturvitenskapelig%20tidsskrift&amp;rft.volume=17&amp;rft.issue=2&amp;rft.aufirst=Jon%20Arild&amp;rft.aulast=Olsen&amp;rft.au=Jon%20Arild%20Olsen&amp;rft.date=2014-08-29&amp;rft.pages=139-144&amp;rft.spage=139&amp;rft.epage=144&amp;rft.issn=0809-2044"></span>
</div>
